Pants Build: Read Me First (Old)
================================

For introductory material, see :doc:`first_concepts` and :doc:`first_tutorial`.

Installing and Troubleshooting Pants Installations
--------------------------------------------------

See :doc:`install`

Target Types
------------

Library Targets
```````````````

See :doc:`first_concepts` and :doc:`first_tutorial`

Binary Targets
``````````````

See :doc:`first_concepts` and :doc:`first_tutorial`

External Dependencies
`````````````````````

See :doc:`3rdparty`

Test Targets
````````````

See :doc:`first_concepts` and :doc:`first_tutorial`

Common Tasks
------------

See :doc:`first_tutorial`

Credits
-------

See :doc:`credits`
